@@ -7,7 +7,9 @@ void gedit_dialog_replace   (gboolean replace);
 void gedit_find_again       (void);
 void gedit_dialog_prefs     (void);
 
-gchar * gedit_plugin_program_location_dialog (void);
+void gedit_dialog_open_uri (void);
+
+gchar * gedit_plugin_program_location_dialog (gchar *program_name, gchar *plugin_name);
 
 void gedit_plugin_manager_create (GtkWidget *widget, gpointer data);
 
