@@ -140,7 +140,7 @@ gedit_document_insert_text_when_mapped (GeditDocument *doc, const gchar * tmp_bu
 	
 
 
-/* TODO : add flash on all operations ....Chema*/
+/* TODO: add flash on all operations ....Chema*/
 /*        what happens when you open the same doc
 	  twice. I think we should add another view
           of the same doc versus opening it twice. Chema*/
@@ -158,7 +158,7 @@ gedit_document_insert_text_when_mapped (GeditDocument *doc, const gchar * tmp_bu
 gint
 gedit_file_open (GeditDocument *doc, const gchar *fname)
 {
-	GnomeVFSFileInfo info;
+	GnomeVFSFileInfo *info;
 	GnomeVFSHandle *from_handle;
 	GnomeVFSResult  result;
 
@@ -184,15 +184,15 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 	while (gtk_events_pending ())
 		  gtk_main_iteration ();
 
-	gnome_vfs_file_info_init (&info);
+	info = gnome_vfs_file_info_new ();
 	result = gnome_vfs_get_file_info (fname, 
-				 &info,
-				 (GNOME_VFS_FILE_INFO_GET_MIME_TYPE
-				 | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
+					  info,
+					  (GNOME_VFS_FILE_INFO_GET_MIME_TYPE
+					   | GNOME_VFS_FILE_INFO_FOLLOW_LINKS));
 
 	if ((result != GNOME_VFS_OK) || 
-	    !(info.valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) ||
-	    (info.type != GNOME_VFS_FILE_TYPE_REGULAR))
+	    !(info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) ||
+	    (info->type != GNOME_VFS_FILE_TYPE_REGULAR))
 	{
 		gchar *errstr = g_strdup_printf (_("An error was encountered while opening the file \"%s\"."
 					"\nPlease make sure the file exists."), fname);
@@ -200,14 +200,14 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 		g_free (errstr);
 
 		if(result == GNOME_VFS_OK)
-			gnome_vfs_file_info_clear (&info);
+			gnome_vfs_file_info_clear (info);
 
 		return 1;
 	}
 
-	if(info.valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE)
+	if(info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE)
 	{
-		tmp_buf = g_string_sized_new (info.size + 1);
+		tmp_buf = g_string_sized_new (info->size + 1);
 	}
 	else
 	{
@@ -220,7 +220,7 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 						   "\nCould not allocate the required memory."), fname);
 		gnome_app_error (gedit_window_active_app(), errstr);
 		g_free (errstr);
-		gnome_vfs_file_info_clear (&info);
+		gnome_vfs_file_info_clear (info);
 
 		return 1;	
 	}
@@ -235,7 +235,7 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 		gnome_app_error (gedit_window_active_app(), errstr);
 		g_free (errstr);
 		g_string_free(tmp_buf, TRUE);
-		gnome_vfs_file_info_clear (&info);
+		gnome_vfs_file_info_clear (info);
 
 		return 1;
 	}
@@ -254,7 +254,7 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 			gnome_app_error (gedit_window_active_app(), errstr);
 			g_free (errstr);
 			g_string_free(tmp_buf, TRUE);
-			gnome_vfs_file_info_clear (&info);
+			gnome_vfs_file_info_clear (info);
 
 			return 1;
 		}
@@ -275,7 +275,7 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 			gnome_app_error (gedit_window_active_app(), errstr);
 			g_free (errstr);
 			g_string_free(tmp_buf, TRUE);
-			gnome_vfs_file_info_clear (&info);
+			gnome_vfs_file_info_clear (info);
 
 			return 1;
 		}
@@ -292,7 +292,7 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 		gnome_app_error (gedit_window_active_app(), errstr);
 		g_free (errstr);
 		g_string_free(tmp_buf, TRUE);
-		gnome_vfs_file_info_clear (&info);
+		gnome_vfs_file_info_clear (info);
 
 		return 1;
 	}
@@ -326,32 +326,31 @@ gedit_file_open (GeditDocument *doc, const gchar *fname)
 
 	if (uri != NULL)
 	{
-
 		scheme = gnome_vfs_uri_get_scheme(uri);
-		
+
 		/* FIXME: all remote files are marked as readonly */
-		if ((scheme != NULL) && (strcmp (scheme, "file") == 0) && GNOME_VFS_FILE_INFO_LOCAL (&info))
+		if ((scheme != NULL) && (strcmp (scheme, "file") == 0) && GNOME_VFS_FILE_INFO_LOCAL (info))
 		{
 			gchar* tmp_str;
-
-			/*
-			tmp_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);	
-			*/
-			tmp_str = gnome_vfs_get_local_path_from_uri (fname);
-				
-			if (tmp_str != NULL)
+		        gchar* tmp_str2;
+												
+			tmp_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_TOPLEVEL_METHOD);				
+			tmp_str2 = gnome_vfs_unescape_string_for_display (tmp_str);
+	
+			if (tmp_str2 != NULL)
 			{
-				gedit_document_set_readonly (doc, access (tmp_str, W_OK) ? TRUE : FALSE);
-				g_free (tmp_str);
-			}
+				gedit_document_set_readonly (doc, access (tmp_str2, W_OK) ? TRUE : FALSE);
+			}			
 
+			g_free (tmp_str2);
+			g_free (tmp_str);
 		}
 		
 		gnome_vfs_uri_unref (uri);
 	}
 	
 	g_string_free (tmp_buf, TRUE);
-	gnome_vfs_file_info_clear (&info);
+	gnome_vfs_file_info_clear (info);
 
 	doc->changed = FALSE;
 	gedit_document_set_title (doc);
@@ -574,7 +573,7 @@ gedit_file_save (GeditDocument *doc, const gchar *fname)
 	
 	if (fputs (buffer, file_pointer) == EOF)
 	{
-		gchar *errstr = g_strdup_printf (_("gedit was unable to save the file :"
+		gchar *errstr = g_strdup_printf (_("gedit was unable to save the file:"
 						   "\n\n %s \n\n"
 						   "Because of an unknown reason (1). Please report this "
 						   "Problem to submit@bugs.gnome.org"), fname);
@@ -592,7 +591,7 @@ gedit_file_save (GeditDocument *doc, const gchar *fname)
 	
 	if (fclose (file_pointer) != 0)
 	{
-		gchar *errstr = g_strdup_printf (_("gedit was unable to save the file :"
+		gchar *errstr = g_strdup_printf (_("gedit was unable to save the file:"
 						   "\n\n %s \n\n"
 						   "Because of an unknown reason (2). Please report this "
 						   "Problem to submit@bugs.gnome.org"), fname);
@@ -714,7 +713,7 @@ gedit_file_stdin (GeditDocument *doc)
 		pos= pos + buffer_length ;
 		if (ferror(stdin)!=0)
 		{
-			gnome_app_error (mdi->active_window, _("Error in the pipe ."));
+			gnome_app_error (mdi->active_window, _("Error in the pipe."));
 			break ;
 		}
 	}
@@ -1244,11 +1243,11 @@ gedit_file_create_popup (const gchar *title)
 	g_free (msg);
 	switch (ret)
 	{
-	case 0 : 
+	case 0: 
 		doc = gedit_document_new_with_title (title);
 		doc->changed = TRUE;
 		return TRUE;
-	case 1 : 
+	case 1: 
 		return FALSE;
 	default:
 		return FALSE;
@@ -1275,7 +1274,7 @@ gedit_close_all_flag_status (guchar * function)
 
 	return;
 	
-	g_print("Close all flag state is : ");
+	g_print("Close all flag state is: ");
 	switch (gedit_close_all_flag){
 	case GEDIT_CLOSE_ALL_FLAG_NORMAL:
 		g_print("NORMAL");
