@@ -68,6 +68,7 @@ gedit_prefs_save_settings (void)
 	gnome_config_set_int ("splitscreen", (gint) settings->splitscreen);
 	gnome_config_set_int ("close_doc", (gint) settings->close_doc);
 	gnome_config_set_int ("undo_levels", (gint) settings->undo_levels);
+	gnome_config_set_int ("tab_size", (gint) settings->tab_size);
 
 	gnome_config_set_int ("bgr", settings->bg[0]);
 	gnome_config_set_int ("bgg", settings->bg[1]);
@@ -98,10 +99,11 @@ gedit_prefs_save_settings (void)
 	gnome_config_set_int ("printorientation", settings->print_orientation);
 	gnome_config_set_string ("font", settings->font);
 
-	if (!settings->run)
+	if (!settings->run) {
 		settings->run = TRUE;
 	
-	gnome_config_set_int ("run", (gint) settings->run);
+		gnome_config_set_int ("run", (gint) settings->run);
+	}
 	
 	gnome_config_pop_prefix ();
 	gnome_config_sync ();
@@ -142,6 +144,7 @@ gedit_prefs_load_settings (void)
 	settings->splitscreen = gnome_config_get_int("splitscreen");
 	settings->close_doc = gnome_config_get_int ("close_doc");
 	settings->undo_levels = gnome_config_get_int ("undo_levels=25");
+	settings->tab_size = gnome_config_get_int ("tab_size=8");
 
 	settings->bg[0] = gnome_config_get_int ("bgr=65535");
 	settings->bg[1] = gnome_config_get_int ("bgg=65535");
