@@ -83,6 +83,7 @@ void	gedit_view_set_font		(GeditView *view, gchar *font);
 void	gedit_view_set_word_wrap	(GeditView *view, gint word_wrap);
 void	gedit_view_set_readonly		(GeditView *view, gint readonly);
 void	gedit_view_set_split_screen	(GeditView *view, gint split_screen);
+void    gedit_view_set_tab_size         (GeditView *view, gint tab_size);
 
 /* Scrolled window */
 gfloat	gedit_view_get_window_position	(GeditView *view);
@@ -101,6 +102,7 @@ void	gedit_view_set_selection	(GeditView *view, guint start, guint end);
 gint	gedit_view_get_selection	(GeditView *view, guint *start, guint *end);
 void	gedit_view_set_position		(GeditView *view, gint pos);
 guint	gedit_view_get_position		(GeditView *view);
+GeditDocument * gedit_view_get_document (GeditView *view);
 
 /* toolbar */
 void	gedit_view_load_widgets (GeditView *view);
